Index: third_party/WebKit/Source/web/WebFrame.cpp |
diff --git a/third_party/WebKit/Source/web/WebFrame.cpp b/third_party/WebKit/Source/web/WebFrame.cpp |
index caf7cdb938cb7bb310fe9839719658ee6e41df3d..ee70aec5a94f3aef30aa7dc3bbc93a3c54448a3d 100644 |
--- a/third_party/WebKit/Source/web/WebFrame.cpp |
+++ b/third_party/WebKit/Source/web/WebFrame.cpp |
@@ -127,12 +127,16 @@ WebSecurityOrigin WebFrame::GetSecurityOrigin() const { |
ToImplBase()->GetFrame()->GetSecurityContext()->GetSecurityOrigin()); |
} |
-void WebFrame::SetFrameOwnerSandboxFlags(WebSandboxFlags flags) { |
- // At the moment, this is only used to replicate sandbox flags |
- // for frames with a remote owner. |
+void WebFrame::SetFrameOwnerPolicy( |
+ WebSandboxFlags flags, |
+ const blink::WebParsedFeaturePolicy& container_policy) { |
+ // At the moment, this is only used to replicate sandbox flags and container |
+ // policy for frames with a remote owner. |
FrameOwner* owner = ToImplBase()->GetFrame()->Owner(); |
DCHECK(owner); |
- ToRemoteFrameOwner(owner)->SetSandboxFlags(static_cast<SandboxFlags>(flags)); |
+ RemoteFrameOwner* remoteOwner = ToRemoteFrameOwner(owner); |
dcheng
2017/04/18 16:26:37
Nit: remote_owner
Or maybe just merge this into l
iclelland
2017/04/18 19:19:44
Whoops. (Didn't use the rebase-helper tool on this
|
+ remoteOwner->SetSandboxFlags(static_cast<SandboxFlags>(flags)); |
+ remoteOwner->SetContainerPolicy(container_policy); |
} |
WebInsecureRequestPolicy WebFrame::GetInsecureRequestPolicy() const { |